local AddonData, PrivateTable = ...

if Heartometer then
	print ("Heartometer already loaded")
	return
end

Heartometer = {
	version=AddonData.toc.Version
}

local function L(x) return Translations.Heartometer.L(x) end

local function ensureVariablesInited()
	if not HeartometerChar then HeartometerChar={} end
	HeartometerChar.width=HeartometerChar.width or 600
	HeartometerChar.height=HeartometerChar.height or 20
	if not HeartometerChar.xpos then HeartometerChar.xpos = 200 end
	if not HeartometerChar.ypos then HeartometerChar.ypos = 200 end
	if HeartometerChar.show==nil then HeartometerChar.show=true end
	
	if not HeartometerShard then HeartometerShard={} end
	if not HeartometerGlobal then HeartometerGlobal={} end
end

local function factionChanged(factions)
	for k, v in pairs(factions) do
		if not Heartometer.StartNotoriety[k] then
			Heartometer.StartNotoriety[k]=v
		end
		if not Heartometer.CurrentNotoriety[k] then
			Heartometer.CurrentNotoriety[k]=v
		end
		if Heartometer.CurrentNotoriety[k] ~= v then
			Heartometer.CurrentNotoriety[k]=v
			HeartometerChar.lastFactionID=k
		end
		if (k==HeartometerChar.lastFactionID and not HeartometerChar.fixedFactionID)
		or (k==HeartometerChar.fixedFactionID) then
			HeartometerUI.UpdateFactionWindow(k)
		end
	end
end

function Heartometer.printVersion()
	LibVersionCheck.register("Heartometer", Heartometer.version)
	print(L("Heartometer Version ") .. (Heartometer.version) .. L(" installed!"))
end

function Heartometer.SlashHandler(args)
	local r = {}
	local numargs = 1
	for token in string.gmatch(args, "[^%s]+") do
		r[numargs] = token
		numargs=numargs+1
	end
	if numargs>1 then
		if r[1] == "version" then
			Heartometer.printVersion()
		elseif r[1] == "show" then
			HeartometerUI.show()
		elseif r[1] == "hide" then
			HeartometerUI.hide()
		elseif r[1] == "lock" then
			HeartometerChar.lock=true
			print (L("Heartometer is fixed to its position; use /heart unlock to unlock."))
		elseif r[1] == "unlock" then
			HeartometerChar.lock=false
			print (L("Heartometer can be moved again."))
		elseif r[1] == "width" then
			HeartometerChar.width=tonumber(r[2])
			HeartometerUI.newSize()
		elseif r[1] == "height" then
			HeartometerChar.height=tonumber(r[2])
			HeartometerUI.newSize()
		else
			print ("Usage: /heart show | hide | lock | unlock | width <n> | height <n>")
		end
	end
end

local function addonLoaded(addon) 
	if (addon == "Heartometer") then
		ensureVariablesInited()
		Heartometer.StartNotoriety=Inspect.Faction.List()
		Heartometer.CurrentNotoriety=Inspect.Faction.List()
		HeartometerUI.create()
		Heartometer.printVersion()
	end
end

table.insert(Event.Faction.Notoriety, 	  		{factionChanged, "Heartometer", "factionChanged"})
table.insert(Command.Slash.Register("heart"), 	{Heartometer.SlashHandler, "Heartometer", "SlashHandler" })
table.insert(Event.Addon.Load.End, 				{addonLoaded, "Heartometer", "AddonLoaded" })
